# Use source code with dual-license
%define pkgname acpica-unix2

Name:		acpica-tools
Version:        20200925
Release:	%mkrel 1
Summary:	ACPICA tools for the development and debug of ACPI tables
License:	GPLv2
Group:		Development/Kernel
URL:            https://www.acpica.org/
Source0:	https://acpica.org/sites/acpica/files/%{pkgname}-%{version}.tar.gz
# Fedora patches:
Patch0:         big-endian.patch
Patch1:         big-endian-dmtbdump.patch
Patch2:         big-endian-dmtbdump1.patch
Patch3:         big-endian-dmtbdump2.patch
Patch4:         big-endian-dmtbdump3.patch
Patch5:         unaligned.patch
Patch6:         OPT_LDFLAGS.patch
Patch7:         int-format.patch
Patch8:         f23-harden.patch
Patch9:         template.patch
Patch10:        ppc64le.patch
Patch11:        arm7hl.patch
Patch12:        big-endian-v2.patch
Patch13:        simple-64bit.patch
Patch14:        mips-be-fix.patch
Patch15:        cve-2017-13693.patch
Patch16:        cve-2017-13694.patch
Patch17:        cve-2017-13695.patch
Patch18:        str-trunc-warn.patch
Patch19:	ptr-cast.patch
Patch20:	aslcodegen.patch
Patch21:	facp.patch
Patch24:	armv7-str-fixes.patch
Patch25:	dbtest.patch
# Mageia patches:
Patch90:		acpica-tools-20150717-Mageia-no_strip_on_install.patch

BuildRequires:	flex >= 2.5.35
BuildRequires:	bison >= 2.4.2
Provides:	iasl = %{version}-%{release}
Obsoletes:	iasl < 20130927

%description
The ACPI Component Architecture (ACPICA) project provides an OS-independent
reference implementation of the Advanced Configuration and Power Interface
Specification (ACPI).  ACPICA code contains those portions of ACPI meant to
be directly integrated into the host OS as a kernel-resident subsystem, and
a small set of tools to assist in developing and debugging ACPI tables.

This package contains only the user-space tools needed for ACPI table
development, not the kernel implementation of ACPI.  The following commands
are installed:
   -- iasl: compiles ASL (ACPI Source Language) into AML (ACPI Machine
      Language), suitable for inclusion as a DSDT in system firmware.
      It also can disassemble AML, for debugging purposes.
   -- acpibin: performs basic operations on binary AML files (e.g.,
      comparison, data extraction)
   -- acpidump: write out the current contents of ACPI tables
   -- acpiexec: simulate AML execution in order to debug method definitions
   -- acpihelp: display help messages describing ASL keywords and op-codes
   -- acpisrc: manipulate the ACPICA source tree and format source files
      for specific environments
   -- acpixtract: extract binary ACPI tables from acpidump output (see
      also the pmtools package)

This version of the tools is being released under GPLv2 license.

%prep
%setup -q -n %{pkgname}-%{version}
%autopatch -p1

# spurious executable permissions on text files in upstream
chmod a-x changes.txt
chmod a-x source/compiler/new_table.txt

%build
sed -i -e 's/_CYGWIN/_LINUX/g' -e 's/-Werror//g' generate/unix/Makefile.config
make -C generate/unix CC="gcc $RPM_OPT_FLAGS"

%install
%make_install
# Fix bin perms
chmod -R u+w %{buildroot}/%{_bindir}/*

%files
%doc changes.txt source/compiler/new_table.txt
%{_bindir}/iasl
%{_bindir}/acpi*


%changelog
* Wed Nov 11 2020 luigiwalser <luigiwalser> 20200925-1.mga8
+ Revision: 1644439
- 20200925
- update patch 13 from fedora
- acpinames command is deprecated (remove from description)

* Thu Apr 16 2020 tv <tv> 20200326-1.mga8
+ Revision: 1567777
- Update to 20200326 source tree, including patch refreshes

* Thu Feb 20 2020 umeabot <umeabot> 20190816-2.mga8
+ Revision: 1545626
- Mageia 8 Mass Rebuild

* Wed Jan 29 2020 tv <tv> 20190816-1.mga8
+ Revision: 1485041
- package more doc
- describe tools in %%description
- Update to 20190816 source tree, including patch refeshes.
- add patches from RC:
  o ARMv7 fixes
  o big endian fixes
  o Add a patch to fix a non-zero exit from iasl -T ALL that actually succeeds
  o leak fixes (cve-2017-13693, cve-2017-13694, cve-2017-13695...)
  o Correct DSDT Address field in FACP tables
  o gcc9 fixes
  o Use proper integer formatting
  o enable to override OPT_LDFLAGS
  o fix on systems requiring aligned memory access
+ wally <wally>
- replace deprecated %%makeinstall_std

* Sun May 12 2019 luigiwalser <luigiwalser> 20190509-1.mga7
+ Revision: 1397343
- 20190509

* Mon Jan 14 2019 luigiwalser <luigiwalser> 20190108-1.mga7
+ Revision: 1356748
- 20190108

* Fri Dec 28 2018 luigiwalser <luigiwalser> 20181213-1.mga7
+ Revision: 1345823
- 20181213

* Sun Sep 23 2018 umeabot <umeabot> 20180313-2.mga7
+ Revision: 1297281
- Mageia 7 Mass Rebuild

* Sun Apr 01 2018 shlomif <shlomif> 20180313-1.mga7
+ Revision: 1214067
- New version ( bug fix update - MGA#22856 )

* Fri Dec 01 2017 mjack <mjack> 20171110-1.mga7
+ Revision: 1180595
- Updated to version 20171110

* Fri Nov 11 2016 luigiwalser <luigiwalser> 20160930-1.mga6
+ Revision: 1066426
- 20160930

* Sat Sep 10 2016 luigiwalser <luigiwalser> 20160831-1.mga6
+ Revision: 1051243
- 20160831

* Thu Aug 11 2016 luigiwalser <luigiwalser> 20160729-1.mga6
+ Revision: 1045482
- 20160729

* Mon May 09 2016 luigiwalser <luigiwalser> 20160422-1.mga6
+ Revision: 1011767
- 20160422

* Sun Apr 17 2016 tv <tv> 20160318-1.mga6
+ Revision: 1003281
- enable build on ARM
- new release

* Mon Jan 25 2016 luigiwalser <luigiwalser> 20160108-1.mga6
+ Revision: 927097
- 20160108

* Thu Dec 31 2015 luigiwalser <luigiwalser> 20151124-1.mga6
+ Revision: 917299
- 20151124
- fix acpinames.h header file name

* Tue Oct 27 2015 ycantin <ycantin> 20150930-1.mga6
+ Revision: 895693
- new version 20150930
- fix spurious perms from upstream

* Fri Aug 14 2015 ycantin <ycantin> 20150717-3.mga6
+ Revision: 864657
- Oops : Also switch to GPLv2 upstream sources
- new version 20150717
- fix empty debuginfo package

* Wed Jul 15 2015 sander85 <sander85> 20150619-1.mga6
+ Revision: 854426
- New version: 20150619

* Wed Oct 08 2014 luigiwalser <luigiwalser> 20140926-1.mga5
+ Revision: 737582
- 20140926

* Tue Sep 16 2014 umeabot <umeabot> 20140828-2.mga5
+ Revision: 677690
- Mageia 5 Mass Rebuild

* Fri Sep 05 2014 luigiwalser <luigiwalser> 20140828-1.mga5
+ Revision: 672380
- 20140828

* Sat Aug 16 2014 dams <dams> 20140724-1.mga5
+ Revision: 664388
- new version 20140724

* Mon Apr 28 2014 dams <dams> 20140424-1.mga5
+ Revision: 618698
- new version 20140424

* Sat Feb 15 2014 dams <dams> 20140214-1.mga5
+ Revision: 591806
- new version 20140214

* Wed Feb 05 2014 dams <dams> 20140114-1.mga5
+ Revision: 582894
- new version 20140114

* Tue Dec 24 2013 dams <dams> 20131115-1.mga5
+ Revision: 560297
- Update %%files
- Update %%summary
- Update %%name
- Update %%license
- Add Provides and Obsoletes on 'iasl'
- New version 20131115
- rename .spec file
- rename as the new project name (mga#12075)
- new version 20130927
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Mon Apr 08 2013 dams <dams> 20130328-1.mga3
+ Revision: 409064
- new version 20130328

* Fri Feb 01 2013 dams <dams> 20130117-1.mga3
+ Revision: 393891
- new version 20130117

* Sat Jan 12 2013 umeabot <umeabot> 20121018-2.mga3
+ Revision: 354034
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Nov 12 2012 dams <dams> 20121018-1.mga3
+ Revision: 317207
- new version 20121018
- remove useless patch

* Sun Sep 09 2012 dams <dams> 20120816-1.mga3
+ Revision: 291244
- new version 20120816
- update specfile to fix build
+ luigiwalser <luigiwalser>
- 20120816

* Fri Jun 01 2012 dams <dams> 20120518-1.mga3
+ Revision: 252753
- new version 20120518

* Fri Nov 18 2011 pterjan <pterjan> 20100528-1.mga2
+ Revision: 168821
- Update to 20100528

* Tue Jan 18 2011 ahmad <ahmad> 20090422-3.mga1
+ Revision: 21910
- imported package iasl

